@@ -1,23 +1,35 @@
-/*	$calcurse: apoint.c,v 1.33 2009/01/03 21:32:11 culot Exp $	*/
+/*	$calcurse: apoint.c,v 1.36 2009-07-12 16:21:58 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -284,7 +296,7 @@ apoint_delete (conf_t *conf, unsigned *nb_events, unsigned *nb_apoints)
   char *del_app_str = _("Do you really want to delete this item ?");
   long date;
   int nb_items = *nb_apoints + *nb_events;
-  bool go_for_deletion = false;
+  unsigned go_for_deletion = 0;
   int to_be_removed = 0;
   int answer = 0;
   int deleted_item_type = 0;
@@ -296,7 +308,7 @@ apoint_delete (conf_t *conf, unsigned *nb_events, unsigned *nb_apoints)
       status_mesg (del_app_str, choices);
       answer = wgetch (win[STA].p);
       if ((answer == 'y') && (nb_items != 0))
-	go_for_deletion = true;
+	go_for_deletion = 1;
       else
 	{
 	  wins_erase_status_bar ();
@@ -304,7 +316,7 @@ apoint_delete (conf_t *conf, unsigned *nb_events, unsigned *nb_apoints)
 	}
     }
   else if (nb_items != 0)
-    go_for_deletion = true;
+    go_for_deletion = 1;
 
   if (go_for_deletion)
     {
@@ -462,14 +474,14 @@ apoint_write (apoint_llist_node_t *o, FILE *f)
 apoint_llist_node_t *
 apoint_scan (FILE *f, struct tm start, struct tm end, char state, char *note)
 {
-  char buf[MESG_MAXSIZE], *newline;
+  char buf[BUFSIZ], *newline;
   time_t tstart, tend, t;
 
   t = time (NULL);
   (void)localtime (&t);
 
   /* Read the appointment description */
-  (void)fgets (buf, MESG_MAXSIZE, f);
+  (void)fgets (buf, sizeof buf, f);
   newline = strchr (buf, '\n');
   if (newline)
     *newline = '\0';
@@ -757,7 +769,7 @@ apoint_update_panel (int which_pan)
       float ratio = ((float) app_length) / ((float) apad.length);
       int sbar_length = (int) (ratio * app_length);
       int highend = (int) (ratio * apad.first_onscreen);
-      bool hilt_bar = (which_pan == APP) ? true : false;
+      unsigned hilt_bar = (which_pan == APP) ? 1 : 0;
       int sbar_top = highend + title_lines + 1;
 
       if ((sbar_top + sbar_length) > win[APP].h - 1)
