@@ -1,23 +1,35 @@
-/*	$calcurse: args.c,v 1.45 2009/01/24 18:45:35 culot Exp $	*/
+/*	$calcurse: args.c,v 1.55 2009-07-12 18:16:11 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -30,6 +42,7 @@
 #include <sys/types.h>
 #include <getopt.h>
 #include <time.h>
+#include <regex.h>
 
 #include "i18n.h"
 #include "custom.h"
@@ -55,7 +68,7 @@ usage ()
   char *arg_usage =
     _("Usage: calcurse [-h|-v] [-N] [-an] [-t[num]] [-i<file>] [-x[format]]\n"
       "                [-d <date>|<num>] [-s[date]] [-r[range]]\n"
-      "                [-c<file> | -D<dir>]\n");
+      "                [-c<file> | -D<dir>] [-S<regex>]\n");
   fputs (arg_usage, stdout);
 }
 
@@ -74,7 +87,7 @@ version_arg ()
 {
   char vtitle[BUFSIZ];
   char *vtext =
-      _("\nCopyright (c) 2004-2008 Frederic Culot.\n"
+      _("\nCopyright (c) 2004-2009 Frederic Culot.\n"
 	"This is free software; see the source for copying conditions.\n");
 
   (void)snprintf (vtitle, BUFSIZ, _("Calcurse %s - text-based organizer\n"),
@@ -124,10 +137,15 @@ help_arg ()
       "\n  -s[date], --startday[=date]\n"
       "	print events and appointments from [date] and exit.\n"
       "\tIf no [date] is given, the current day is considered.\n"
+      "\n  -S<regex>, --search=<regex>\n"
+      "	search for the given regular expression within events, appointments,\n"
+      "\tand todos description.\n"
       "\n  -t[num], --todo[=num]\n"
       "	print todo list and exit. If the optional number [num] is given,\n"
       "\tthen only todos having a priority equal to [num] will be returned.\n"
-      "\tnote: priority number must be between 1 (highest) and 9 (lowest).\n"
+      "\tThe priority number must be between 1 (highest) and 9 (lowest).\n"
+      "\tIt is also possible to specify '0' for the priority, in which case\n"
+      "\tonly completed tasks will be shown.\n"
       "\n  -x[format], --export[=format]\n"
       "	export user data to the specified format. Events, appointments and\n"
       "\ttodos are converted and echoed to stdout.\n"
@@ -194,34 +212,65 @@ print_notefile (FILE *out, char *filename, int nbtab)
 }
 
 /*
- * Print todo list and exit. If a priority number is given (say not equal to
- * zero), then only todo items that have this priority will be displayed.
+ * Print todo list and exit. If a priority number is given, then only todo
+ * then only todo items that have this priority will be displayed.
+ * If priority is < 0, all todos will be displayed.
+ * If priority == 0, only completed tasks will be displayed.
+ * If regex is not null, only the matching todos are printed.
  */
 static void
-todo_arg (int priority, int print_note)
+todo_arg (int priority, int print_note, regex_t *regex)
 {
   struct todo_s *i;
   int title = 1;
-  char priority_str[BUFSIZ] = "";
+  char *titlestr, priority_str[BUFSIZ] = "";
+  char *all_todos_title = _("to do:\n");
+  char *completed_title = _("completed tasks:\n");
 
-  io_load_todo ();
+  titlestr = priority == 0 ? completed_title : all_todos_title;
+
+#define DISPLAY_TITLE  do {                                             \
+  if (title)                                                            \
+    {                                                                   \
+      fputs (titlestr, stdout);                                         \
+      title = 0;                                                        \
+    }                                                                   \
+  } while (0)
+
+#define DISPLAY_TODO  do {                                              \
+  (void)snprintf (priority_str, BUFSIZ, "%d. ", abs (i->id));           \
+  fputs (priority_str, stdout);                                         \
+  fputs (i->mesg, stdout);                                              \
+  fputs ("\n", stdout);                                                 \
+  if (print_note && i->note)                                            \
+    print_notefile (stdout, i->note, 1);                                \
+  } while (0)
+  
   for (i = todolist; i != 0; i = i->next)
     {
-      if (priority == 0 || i->id == priority)
-	{
-	  if (title)
-	    {
-	      fputs (_("to do:\n"), stdout);
-	      title = 0;
-	    }
-	  (void)snprintf (priority_str, BUFSIZ, "%d. ", i->id);
-	  fputs (priority_str, stdout);
-	  fputs (i->mesg, stdout);
-	  fputs ("\n", stdout);
-	  if (print_note && i->note)
-	    print_notefile (stdout, i->note, 1);
-	}
+      if (regex && regexec (regex, i->mesg, 0, 0, 0) != 0)
+        continue;
+      
+      if (i->id < 0) /* completed task */
+        {
+          if (priority == 0)
+            {
+              DISPLAY_TITLE;
+              DISPLAY_TODO;
+            }
+        }
+      else
+        {
+          if (priority < 0 || i->id == priority)
+            {
+              DISPLAY_TITLE;
+              DISPLAY_TODO;
+            }
+        }
     }
+
+#undef DISPLAY_TITLE
+#undef DISPLAY_TODO  
 }
 
 /* Print the next appointment within the upcoming 24 hours. */
@@ -274,16 +323,18 @@ arg_print_date (long date, conf_t *conf)
  * Print appointments for given day and exit.
  * If no day is given, the given date is used.
  * If there is also no date given, current date is considered.
+ * If regex is not null, only the matching appointments or events are printed.
  */
 static int
-app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
+app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf,
+         regex_t *regex)
 {
   struct recur_event_s *re;
   struct event_s *j;
   recur_apoint_llist_node_t *ra;
   apoint_llist_node_t *i;
   long today;
-  bool print_date = true;
+  unsigned print_date = 1;
   int app_found = 0;
   char apoint_start_time[100];
   char apoint_end_time[100];
@@ -303,6 +354,9 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
       if (recur_item_inday (re->day, re->exc, re->rpt->type, re->rpt->freq,
                             re->rpt->until, today))
 	{
+          if (regex && regexec (regex, re->mesg, 0, 0, 0) != 0)
+            continue;
+          
 	  app_found = 1;
 	  if (add_line)
 	    {
@@ -312,7 +366,7 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
 	  if (print_date)
 	    {
 	      arg_print_date (today, conf);
-	      print_date = false;
+	      print_date = 0;
 	    }
 	  fputs (" * ", stdout);
 	  fputs (re->mesg, stdout);
@@ -326,6 +380,9 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
     {
       if (event_inday (j, today))
 	{
+          if (regex && regexec (regex, j->mesg, 0, 0, 0) != 0)
+            continue;
+          
 	  app_found = 1;
 	  if (add_line)
 	    {
@@ -335,7 +392,7 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
 	  if (print_date)
 	    {
 	      arg_print_date (today, conf);
-	      print_date = false;
+	      print_date = 0;
 	    }
 	  fputs (" * ", stdout);
 	  fputs (j->mesg, stdout);
@@ -352,6 +409,9 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
       if (recur_item_inday (ra->start, ra->exc, ra->rpt->type, ra->rpt->freq,
                             ra->rpt->until, today))
 	{
+          if (regex && regexec (regex, ra->mesg, 0, 0, 0) != 0)
+            continue;
+          
 	  app_found = 1;
 	  if (add_line)
 	    {
@@ -361,7 +421,7 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
 	  if (print_date)
 	    {
 	      arg_print_date (today, conf);
-	      print_date = false;
+	      print_date = 0;
 	    }
 	  apoint_sec2str (apoint_recur_s2apoint_s (ra), RECUR_APPT, today,
                           apoint_start_time, apoint_end_time);
@@ -383,6 +443,9 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
     {
       if (apoint_inday (i, today))
 	{
+          if (regex && regexec (regex, i->mesg, 0, 0, 0) != 0)
+            continue;
+          
 	  app_found = 1;
 	  if (add_line)
 	    {
@@ -392,7 +455,7 @@ app_arg (int add_line, date_t *day, long date, int print_note, conf_t *conf)
 	  if (print_date)
 	    {
 	      arg_print_date (today, conf);
-	      print_date = false;
+	      print_date = 0;
 	    }
 	  apoint_sec2str (i, APPT, today, apoint_start_time, apoint_end_time);
 	  fputs (" - ", stdout);
@@ -427,7 +490,7 @@ more_info (void)
  */
 static void
 display_app (struct tm *t, int numdays, int add_line, int print_note,
-             conf_t *conf)
+             conf_t *conf, regex_t *regex)
 {
   int i, app_found;
   date_t day;
@@ -437,7 +500,7 @@ display_app (struct tm *t, int numdays, int add_line, int print_note,
       day.dd = t->tm_mday;
       day.mm = t->tm_mon + 1;
       day.yyyy = t->tm_year + 1900;
-      app_found = app_arg (add_line, &day, 0, print_note, conf);
+      app_found = app_arg (add_line, &day, 0, print_note, conf, regex);
       if (app_found)
         add_line = 1;
       t->tm_mday++;
@@ -450,7 +513,8 @@ display_app (struct tm *t, int numdays, int add_line, int print_note,
  * days.
  */
 static void
-date_arg (char *ddate, int add_line, int print_note, conf_t *conf)
+date_arg (char *ddate, int add_line, int print_note, conf_t *conf,
+          regex_t *regex)
 {
   int i;
   date_t day;
@@ -481,14 +545,14 @@ date_arg (char *ddate, int add_line, int print_note, conf_t *conf)
        */
       timer = time (NULL);
       t = *localtime (&timer);
-      display_app (&t, numdays, add_line, print_note, conf);
+      display_app (&t, numdays, add_line, print_note, conf, regex);
     }
   else
     {				/* a date was entered */
       if (parse_date (ddate, conf->input_datefmt, (int *)&day.yyyy,
                       (int *)&day.mm, (int *)&day.dd))
 	{
-	  app_found = app_arg (add_line, &day, 0, print_note, conf);
+	  app_found = app_arg (add_line, &day, 0, print_note, conf, regex);
 	}
       else
 	{
@@ -513,7 +577,7 @@ date_arg (char *ddate, int add_line, int print_note, conf_t *conf)
  */
 static void
 date_arg_extended (char *startday, char *range, int add_line, int print_note,
-                   conf_t *conf)
+                   conf_t *conf, regex_t *regex)
 {
   int i, numdays = 1, error = 0, arg_len = 0;
   static struct tm t;
@@ -551,7 +615,7 @@ date_arg_extended (char *startday, char *range, int add_line, int print_note,
     }
   if (!error)
     {
-      display_app (&t, numdays, add_line, print_note, conf);
+      display_app (&t, numdays, add_line, print_note, conf, regex);
     }
   else
     {
@@ -587,17 +651,17 @@ parse_args (int argc, char **argv, conf_t *conf)
   int Nflag = 0;    /* -N: also print note content with apps and todos */
   int rflag = 0;    /* -r: specify the range of days to consider */
   int sflag = 0;    /* -s: specify the first day to consider */
+  int Sflag = 0;    /* -S: specify a regex to search for */
   int tflag = 0;    /* -t: print todo list */
   int vflag = 0;    /* -v: print version number */
   int xflag = 0;    /* -x: export data */
 
-  int tnum = 0, xfmt = 0;
-  int non_interactive = 0, multiple_flag = 0, load_data = 0;
-  int no_file = 1;
+  int tnum = 0, xfmt = 0, non_interactive = 0, multiple_flag = 0, load_data = 0;
   char *ddate = "", *cfile = NULL, *range = NULL, *startday = NULL;
   char *datadir = NULL, *ifile = NULL;
+  regex_t reg, *preg = NULL;
 
-  static char *optstr = "hvnNax::t::d:c:r:s:D:i:";
+  static char *optstr = "hvnNax::t::d:c:r::s::S:D:i:";
 
   struct option longopts[] = {
     {"appointment", no_argument, NULL, 'a'},
@@ -608,8 +672,9 @@ parse_args (int argc, char **argv, conf_t *conf)
     {"import", required_argument, NULL, 'i'},
     {"next", no_argument, NULL, 'n'},
     {"note", no_argument, NULL, 'N'},
-    {"range", required_argument, NULL, 'r'},
-    {"startday", required_argument, NULL, 's'},
+    {"range", optional_argument, NULL, 'r'},
+    {"startday", optional_argument, NULL, 's'},
+    {"search", required_argument, NULL, 'S'},
     {"todo", optional_argument, NULL, 't'},
     {"version", no_argument, NULL, 'v'},
     {"export", optional_argument, NULL, 'x'},
@@ -623,18 +688,18 @@ parse_args (int argc, char **argv, conf_t *conf)
 	case 'a':
 	  aflag = 1;
 	  multiple_flag++;
-	  load_data++;
+          load_data++;
 	  break;
 	case 'c':
 	  cflag = 1;
 	  multiple_flag++;
-	  load_data++;
 	  cfile = optarg;
+          load_data++;
 	  break;
 	case 'd':
 	  dflag = 1;
 	  multiple_flag++;
-	  load_data++;
+          load_data++;
 	  ddate = optarg;
 	  break;
         case 'D':
@@ -647,13 +712,13 @@ parse_args (int argc, char **argv, conf_t *conf)
         case 'i':
           iflag = 1;
           multiple_flag++;
-	  load_data++;
+          load_data++;
           ifile = optarg;
           break;
 	case 'n':
 	  nflag = 1;
 	  multiple_flag++;
-	  load_data++;
+          load_data++;
 	  break;
 	case 'N':
 	  Nflag = 1;
@@ -670,15 +735,23 @@ parse_args (int argc, char **argv, conf_t *conf)
           load_data++;
           startday = optarg;
           break;
+        case 'S':
+          EXIT_IF (Sflag > 0,
+                   _("Can not handle more than one regular expression."));
+          Sflag = 1;
+          if (regcomp (&reg, optarg, REG_EXTENDED))
+            EXIT (_("Could not compile regular expression."));
+          preg = &reg;
+          break;
 	case 't':
 	  tflag = 1;
 	  multiple_flag++;
-	  load_data++;
+          load_data++;
 	  add_line = 1;
 	  if (optarg != NULL)
 	    {
 	      tnum = atoi (optarg);
-	      if (tnum < 1 || tnum > 9)
+	      if (tnum < 0 || tnum > 9)
 		{
 		  usage ();
 		  usage_try ();
@@ -686,7 +759,7 @@ parse_args (int argc, char **argv, conf_t *conf)
 		}
 	    }
 	  else
-	    tnum = 0;
+	    tnum = -1;
 	  break;
 	case 'v':
 	  vflag = 1;
@@ -694,7 +767,7 @@ parse_args (int argc, char **argv, conf_t *conf)
 	case 'x':
 	  xflag = 1;
 	  multiple_flag++;
-	  load_data++;
+          load_data++;
           if (optarg != NULL)
             {
               if (strcmp (optarg, "ical") == 0)
@@ -741,6 +814,14 @@ parse_args (int argc, char **argv, conf_t *conf)
       usage_try ();
       return EXIT_FAILURE;
     }
+  else if (Sflag && !(aflag || dflag || rflag || sflag || tflag))
+    {
+      fputs (_("Option '-S' must be used with either '-d', '-r', '-s', "
+               "'-a' or '-t'\n"), stderr);
+      usage ();
+      usage_try ();
+      return EXIT_FAILURE;
+    }
   else
     {
       if (unknown_flag)
@@ -762,64 +843,71 @@ parse_args (int argc, char **argv, conf_t *conf)
 	  if (load_data)
 	    {
 	      io_init (cfile, datadir);
-	      no_file = io_check_data_files ();
-	      if (dflag || aflag || nflag || iflag || xflag || rflag || sflag)
-                {
-                  vars_init (conf);
-                  custom_load_conf (conf, 0);
-                  io_load_keys (conf->pager);
-                  io_load_app ();
-                  io_load_todo ();
-                }
 	    }
           if (iflag)
             {
-              notify_init_vars ();
+              io_check_file (path_apts, (int *)0);
+              io_check_file (path_todo, (int *)0);              
+              io_load_app ();
+              io_load_todo ();
               io_import_data (IO_IMPORT_ICAL, conf, ifile);
-              io_save_cal (conf, IO_SAVE_DISPLAY_NONE);
+              io_save_apts ();
+              io_save_todo ();
               non_interactive = 1;
             }
 	  if (xflag)
 	    {
-	      notify_init_vars ();
+              io_check_file (path_apts, (int *)0);
+              io_check_file (path_todo, (int *)0);
+              io_load_app ();
+              io_load_todo ();
 	      io_export_data (xfmt, conf);
 	      non_interactive = 1;
 	      return non_interactive;
 	    }
 	  if (tflag)
 	    {
-	      todo_arg (tnum, Nflag);
+              io_load_todo ();              
+	      todo_arg (tnum, Nflag, preg);
 	      non_interactive = 1;
 	    }
 	  if (nflag)
 	    {
+              io_load_app ();
 	      next_arg ();
 	      non_interactive = 1;
 	    }
 	  if (dflag || rflag || sflag)
 	    {
-	      notify_init_vars ();
+              io_load_app ();
               if (dflag)
-                date_arg (ddate, add_line, Nflag, conf);
+                date_arg (ddate, add_line, Nflag, conf, preg);
               if (rflag || sflag)
-                date_arg_extended (startday, range, add_line, Nflag, conf);
+                date_arg_extended (startday, range, add_line, Nflag, conf,
+                                   preg);
 	      non_interactive = 1;
 	    }
 	  else if (aflag)
 	    {
 	      date_t day;
+
+              vars_init (conf);
+              custom_load_conf (conf, 0); /* To get output date format. */
+              io_load_app ();
 	      day.dd = day.mm = day.yyyy = 0;
-	      notify_init_vars ();
-	      app_found = app_arg (add_line, &day, 0, Nflag, conf);
+	      app_found = app_arg (add_line, &day, 0, Nflag, conf, preg);
 	      non_interactive = 1;
 	    }
 	}
       else
 	{
 	  non_interactive = 0;
-	  io_init (cfile, datadir);
-	  no_file = io_check_data_files ();
+          io_init (cfile, datadir);
 	}
     }
+
+  if (preg)
+    regfree (preg);
+  
   return non_interactive;  
 }
