@@ -1,23 +1,35 @@
-/*	$calcurse: calcurse.c,v 1.78 2009/01/24 18:45:35 culot Exp $	*/
+/*	$calcurse: calcurse.c,v 1.83 2009-07-12 20:37:41 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -62,9 +74,9 @@ main (int argc, char **argv)
   int sav_hilt_tod = 0;
   int cut_item = 0;
   struct sigaction sigact;
-  bool do_storage = false;
-  bool do_update = true;
-  bool day_changed = false;
+  unsigned do_storage = 0;
+  unsigned do_update = 1;
+  unsigned day_changed = 0;
   char *no_color_support =
       _("Sorry, colors are not supported by your terminal\n"
 	"(Press [ENTER] to continue)");
@@ -88,7 +100,12 @@ main (int argc, char **argv)
   non_interactive = parse_args (argc, argv, &conf);
   if (non_interactive)
     exit_calcurse (EXIT_SUCCESS);
-
+  else
+    {
+      no_data_file = io_check_data_files ();
+      io_set_lock ();
+    }
+  
   /* Begin of interactive mode with ncurses interface. */
   sigs_init (&sigact);		/* signal handling init */
   initscr ();			/* start the curses mode */
@@ -102,7 +119,7 @@ main (int argc, char **argv)
   /* Check if terminal supports color. */
   if (has_colors ())
     {
-      colorize = true;
+      colorize = 1;
       background = COLOR_BLACK;
       foreground = COLOR_WHITE;
       start_color ();
@@ -129,7 +146,7 @@ main (int argc, char **argv)
     }
   else
     {
-      colorize = false;
+      colorize = 0;
       background = COLOR_BLACK;
     }
 
@@ -144,7 +161,6 @@ main (int argc, char **argv)
    * configuration (the display is then updated), and then
    * the todo list, appointments and events.
    */
-  no_data_file = io_check_data_files ();
   custom_load_conf (&conf, background);
   wins_erase_status_bar ();
   io_load_keys (conf.pager);
@@ -167,17 +183,17 @@ main (int argc, char **argv)
     {
       int key;
       
-      do_update = true;
+      do_update = 1;
       key = keys_getch (win[STA].p);
       switch (key)
 	{
 	case ERR:
-	  do_update = false;
+	  do_update = 0;
 	  break;
 
 	case KEY_GENERIC_REDRAW:
 	case KEY_RESIZE:
-	  do_update = false;
+	  do_update = 0;
 	  wins_reset ();
 	  break;
 
@@ -232,8 +248,8 @@ main (int argc, char **argv)
             calendar_goto_today ();
           else
             calendar_change_day (conf.input_datefmt);
-	  do_storage = true;
-	  day_changed = true;
+	  do_storage = 1;
+	  day_changed = 1;
 	  break;
 
         case KEY_VIEW_ITEM:
@@ -256,7 +272,7 @@ main (int argc, char **argv)
 		    custom_color_config ();
 		  else
 		    {
-		      colorize = false;
+		      colorize = 0;
 		      wins_erase_status_bar ();
 		      mvwprintw (win[STA].p, 0, 0, _(no_color_support));
 		      wgetch (win[STA].p);
@@ -281,7 +297,7 @@ main (int argc, char **argv)
 		}
 	      wins_reset ();
 	      wins_update ();
-	      do_storage = true;
+	      do_storage = 1;
 	      wins_erase_status_bar ();
 	      custom_config_bar ();
 	    }
@@ -290,7 +306,7 @@ main (int argc, char **argv)
 
         case KEY_GENERIC_ADD_APPT:
 	  apoint_add ();
-	  do_storage = true;
+	  do_storage = 1;
 	  break;
 
         case KEY_GENERIC_ADD_TODO:
@@ -304,7 +320,7 @@ main (int argc, char **argv)
 	    {
 	    case APP:
 	      apoint_add ();
-	      do_storage = true;
+	      do_storage = 1;
 	      break;
 	    case TOD:
 	      todo_new_item ();
@@ -321,7 +337,7 @@ main (int argc, char **argv)
 	    day_edit_item (&conf);
 	  else if (wins_slctd () == TOD && todo_hilt () != 0)
 	    todo_edit_item ();
-	  do_storage = true;
+	  do_storage = 1;
 	  break;
 
         case KEY_DEL_ITEM:
@@ -329,14 +345,14 @@ main (int argc, char **argv)
 	    apoint_delete (&conf, &inday.nb_events, &inday.nb_apoints);
 	  else if (wins_slctd () == TOD && todo_hilt () != 0)
 	    todo_delete (&conf);
-	  do_storage = true;
+	  do_storage = 1;
 	  break;
 
         case KEY_GENERIC_CUT:
           if (wins_slctd () == APP && apoint_hilt () != 0)
             {
               cut_item = apoint_cut (&inday.nb_events, &inday.nb_apoints);
-              do_storage = true;
+              do_storage = 1;
             }
           break;
 
@@ -345,20 +361,22 @@ main (int argc, char **argv)
             {
               apoint_paste (&inday.nb_events, &inday.nb_apoints, cut_item);
               cut_item = 0;
-              do_storage = true;
+              do_storage = 1;
             }
           break;
           
         case KEY_REPEAT_ITEM:
 	  if (wins_slctd () == APP && apoint_hilt () != 0)
 	    recur_repeat_item (&conf);
-	  do_storage = true;
+	  do_storage = 1;
 	  break;
 
         case KEY_FLAG_ITEM:
 	  if (wins_slctd () == APP && apoint_hilt () != 0)
 	    apoint_switch_notify ();
-	  do_storage = true;
+          else if (wins_slctd () == TOD && todo_hilt () != 0)
+            todo_flag ();
+	  do_storage = 1;
 	  break;
 
         case KEY_RAISE_PRIORITY:
@@ -378,7 +396,7 @@ main (int argc, char **argv)
 	    day_edit_note (conf.editor);
 	  else if (wins_slctd () == TOD && todo_hilt () != 0)
 	    todo_edit_note (conf.editor);
-	  do_storage = true;
+	  do_storage = 1;
 	  break;
 
         case KEY_VIEW_NOTE:
@@ -400,7 +418,7 @@ main (int argc, char **argv)
         case KEY_GENERIC_IMPORT:
           wins_erase_status_bar ();
           io_import_data (IO_IMPORT_ICAL, &conf, NULL);
-          do_storage = true;
+          do_storage = 1;
           break;
           
         case KEY_GENERIC_EXPORT:
@@ -421,7 +439,7 @@ main (int argc, char **argv)
 		}
 	      wins_reset ();
 	      wins_update ();
-	      do_storage = true;
+	      do_storage = 1;
 	      wins_erase_status_bar ();
 	      io_export_bar ();
 	    }
@@ -432,8 +450,8 @@ main (int argc, char **argv)
         case KEY_MOVE_RIGHT:
 	  if (wins_slctd () == CAL || key == KEY_GENERIC_NEXT_DAY)
 	    {
-	      do_storage = true;
-	      day_changed = true;
+	      do_storage = 1;
+	      day_changed = 1;
 	      calendar_move (RIGHT);
 	    }
 	  break;
@@ -442,8 +460,8 @@ main (int argc, char **argv)
         case KEY_MOVE_LEFT:
 	  if (wins_slctd () == CAL || key == KEY_GENERIC_PREV_DAY)
 	    {
-	      do_storage = true;
-	      day_changed = true;
+	      do_storage = 1;
+	      day_changed = 1;
 	      calendar_move (LEFT);
 	    }
 	  break;
@@ -452,8 +470,8 @@ main (int argc, char **argv)
         case KEY_MOVE_UP:
 	  if (wins_slctd () == CAL || key == KEY_GENERIC_PREV_WEEK)
 	    {
-	      do_storage = true;
-	      day_changed = true;
+	      do_storage = 1;
+	      day_changed = 1;
 	      calendar_move (UP);
 	    }
           else if ((wins_slctd () == APP) && (apoint_hilt () > 1))
@@ -473,8 +491,8 @@ main (int argc, char **argv)
         case KEY_MOVE_DOWN:
 	  if (wins_slctd () == CAL || key == KEY_GENERIC_NEXT_WEEK)
 	    {
-	      do_storage = true;
-	      day_changed = true;
+	      do_storage = 1;
+	      day_changed = 1;
 	      calendar_move (DOWN);
 	    }
           else if ((wins_slctd () == APP) &&
@@ -494,8 +512,8 @@ main (int argc, char **argv)
         case KEY_START_OF_WEEK:
           if (wins_slctd () == CAL)
 	    {
-	      do_storage = true;
-	      day_changed = true;
+	      do_storage = 1;
+	      day_changed = 1;
 	      calendar_move (WEEK_START);
 	    }
           break;
@@ -503,8 +521,8 @@ main (int argc, char **argv)
         case KEY_END_OF_WEEK:
           if (wins_slctd () == CAL)
 	    {
-	      do_storage = true;
-	      day_changed = true;
+	      do_storage = 1;
+	      day_changed = 1;
 	      calendar_move (WEEK_END);
 	    }
           break;
@@ -530,7 +548,7 @@ main (int argc, char **argv)
 	  break;
 
 	default:
-	  do_update = false;
+	  do_update = 0;
 	  break;
 	}
 
