@@ -1,23 +1,35 @@
-/*	$calcurse: calendar.c,v 1.22 2009/01/24 20:41:52 culot Exp $	*/
+/*	$calcurse: calendar.c,v 1.25 2009-07-12 16:21:59 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -57,7 +69,7 @@
 #define isleap(y) ((((y) % 4) == 0 && ((y) % 100) != 0) || ((y) % 400) == 0)
 
 static date_t today, slctd_day;
-static bool week_begins_on_monday;
+static unsigned week_begins_on_monday;
 static pthread_mutex_t date_thread_mutex = PTHREAD_MUTEX_INITIALIZER;
 static pthread_t calendar_t_date;
 
@@ -120,14 +132,14 @@ calendar_set_first_day_of_week (wday_e first_day)
   switch (first_day)
     {
     case SUNDAY:
-      week_begins_on_monday = false;
+      week_begins_on_monday = 0;
       break;
     case MONDAY:
-      week_begins_on_monday = true;
+      week_begins_on_monday = 1;
       break;
     default:
       ERROR_MSG (_("ERROR setting first day of week"));
-      week_begins_on_monday = false;
+      week_begins_on_monday = 0;
       /* NOTREACHED */
     }
 }
@@ -139,8 +151,8 @@ calendar_change_first_day_of_week (void)
   week_begins_on_monday = !week_begins_on_monday;
 }
 
-/* Return true if week begins on monday, false otherwise. */
-bool
+/* Return 1 if week begins on monday, 0 otherwise. */
+unsigned
 calendar_week_begins_on_monday (void)
 {
   return (week_begins_on_monday);
@@ -245,20 +257,20 @@ calendar_update_panel (WINDOW *cwin)
   c_day_1 = (int) ((ymd_to_scalar (yr, mo, 1 + sunday_first) - (long) 1) % 7L);
 
   /* Write the current month and year on top of the calendar */
-  custom_apply_attr (cwin, ATTR_HIGH);
+  custom_apply_attr (cwin, ATTR_HIGHEST);
   mvwprintw (cwin, ofs_y, (CALWIDTH - (strlen (_(monthnames[mo - 1])) + 5)) / 2,
 	     "%s %d", _(monthnames[mo - 1]), slctd_day.yyyy);
-  custom_remove_attr (cwin, ATTR_HIGH);
+  custom_remove_attr (cwin, ATTR_HIGHEST);
   ++ofs_y;
 
   /* print the days, with regards to the first day of the week */
-  custom_apply_attr (cwin, ATTR_HIGH);
+  custom_apply_attr (cwin, ATTR_HIGHEST);
   for (j = 0; j < 7; j++)
     {
       mvwprintw (cwin, ofs_y, ofs_x + 4 * j, "%s",
 		 _(daynames[1 + j - sunday_first]));
     }
-  custom_remove_attr (cwin, ATTR_HIGH);
+  custom_remove_attr (cwin, ATTR_HIGHEST);
 
   day_1_sav = (c_day_1 + 1) * 3 + c_day_1 - 7;
 
@@ -293,21 +305,21 @@ calendar_update_panel (WINDOW *cwin)
 		|| (current_day.mm != slctd_day.mm)
 		|| (current_day.yyyy != slctd_day.yyyy)))
 	{
-	  /* This is the selected day, print it in red. */
-	  custom_apply_attr (cwin, ATTR_MIDDLE);
+	  /* This is the selected day, print it according to user's theme. */
+	  custom_apply_attr (cwin, ATTR_HIGHEST);
 	  mvwprintw (cwin, ofs_y + 1, ofs_x + day_1_sav + 4 * c_day + 1, "%2d",
                      c_day);
-	  custom_remove_attr (cwin, ATTR_MIDDLE);
+	  custom_remove_attr (cwin, ATTR_HIGHEST);
 	}
       else if (c_day == slctd_day.dd && current_day.dd == slctd_day.dd
 	       && current_day.mm == slctd_day.mm
 	       && current_day.yyyy == slctd_day.yyyy)
 	{
 	  /* today is the selected day */
-	  custom_apply_attr (cwin, ATTR_MIDDLE);
+	  custom_apply_attr (cwin, ATTR_HIGHEST);
 	  mvwprintw (cwin, ofs_y + 1, ofs_x + day_1_sav + 4 * c_day + 1, "%2d",
                      c_day);
-	  custom_remove_attr (cwin, ATTR_MIDDLE);
+	  custom_remove_attr (cwin, ATTR_HIGHEST);
 	}
       else if (item_this_day)
 	{
