@@ -1,23 +1,35 @@
-/*	$calcurse: custom.c,v 1.37 2009/01/24 14:44:25 culot Exp $	*/
+/*	$calcurse: custom.c,v 1.41 2009-07-12 17:55:13 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -43,17 +55,17 @@
 
 static struct attribute_s attr;
 
-static bool
+static unsigned
 fill_config_var (char *string)
 {
   if (strncmp (string, "yes", 3) == 0)
-    return (true);
+    return 1;
   else if (strncmp (string, "no", 2) == 0)
-    return (false);
+    return 0;
   else
     {
       EXIT (_("wrong configuration variable format."));
-      return false;
+      return 0;
     }
 }
 
@@ -117,7 +129,7 @@ custom_load_color (char *color, int background)
       switch (color_num)
 	{
 	case 0:
-	  colorize = false;
+	  colorize = 0;
 	  break;
 	case 1:
 	  init_pair (COLR_CUSTOM, COLOR_RED, background);
@@ -436,8 +448,7 @@ display_layout_config (window_t *lwin, int mark, int cursor, int need_reset)
     {
       char label[BUFSIZ];
       
-      (void)snprintf (label, BUFSIZ, _("CalCurse %s | layout configuration"),
-                      VERSION);
+      (void)snprintf (label, BUFSIZ, _("layout configuration"));
       custom_confwin_init (lwin, label);
     }
 
@@ -542,6 +553,14 @@ custom_layout_config (void)
 #undef NBLAYOUTS
 #undef LAYOUTSPERCOL
 
+static void
+set_confwin_attr (window_t *cwin)
+{
+  cwin->h = (notify_bar ())? row - 3 : row - 2;
+  cwin->w = col;
+  cwin->x = cwin->y = 0;
+}
+
 /* 
  * Create a configuration window and initialize status and notification bar 
  * (useful in case of window resize).
@@ -557,8 +576,8 @@ custom_confwin_init (window_t *confwin, char *label)
     }
   
   wins_get_config ();
-  confwin->h = (notify_bar ())? row - 3 : row - 2;
-  confwin->p = newwin (confwin->h, col, 0, 0);
+  set_confwin_attr (confwin);
+  confwin->p = newwin (confwin->h, col, 0, 0);  
   box (confwin->p, 0, 0);
   wins_show (confwin->p, label);
   delwin (win[STA].p);
@@ -641,7 +660,7 @@ display_color_config (window_t *cwin, int *mark_fore, int *mark_back,
 
   if (need_reset)
     {
-      (void)snprintf (label, BUFSIZ, _("CalCurse %s | color theme"), VERSION);
+      (void)snprintf (label, BUFSIZ, _("color theme"));
       custom_confwin_init (cwin, label);
     }
 
@@ -735,6 +754,7 @@ custom_color_config (void)
   need_reset = 1;
   theme_changed = 0;
   conf_win.p = 0;
+  set_confwin_attr (&conf_win);
   display_color_config (&conf_win, &mark_fore, &mark_back, cursor,
 			need_reset, theme_changed);
 
@@ -753,7 +773,7 @@ custom_color_config (void)
 	  break;
 
 	case KEY_GENERIC_SELECT:
-	  colorize = true;
+	  colorize = 1;
 	  need_reset = 1;
 	  theme_changed = 1;
 	  if (cursor > NBUSERCOLORS)
@@ -783,7 +803,7 @@ custom_color_config (void)
 	  break;
 
 	case KEY_GENERIC_CANCEL:
-	  colorize = false;
+	  colorize = 0;
 	  need_reset = 1;
 	  break;
 	}
@@ -982,8 +1002,7 @@ custom_general_config (conf_t *conf)
 
   clear ();
   conf_set_scrsize (&cwin);
-  (void)snprintf (cwin.label, BUFSIZ, _("CalCurse %s | general options"),
-                  VERSION);
+  (void)snprintf (cwin.label, BUFSIZ, _("general options"));
   wins_scrollwin_init (&cwin);
   wins_show (cwin.win.p, cwin.label);
   status_mesg (number_str, keys);
@@ -1182,8 +1201,7 @@ custom_keys_config (void)
   clear ();
   conf_set_scrsize (&kwin);
   nbdisplayed = (kwin.win.h - LABELLINES) / LINESPERKEY;
-  (void)snprintf (kwin.label, BUFSIZ, _("CalCurse %s | keys configuration"),
-                  VERSION);
+  (void)snprintf (kwin.label, BUFSIZ, _("keys configuration"));
   wins_scrollwin_init (&kwin);
   wins_show (kwin.win.p, kwin.label);
   custom_keys_config_bar ();
