@@ -1,23 +1,35 @@
-/*	$calcurse: day.c,v 1.48 2009/01/03 21:32:11 culot Exp $	*/
+/*	$calcurse: day.c,v 1.50 2009-07-12 16:22:00 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -283,7 +295,7 @@ day_store_items (long date, unsigned *pnb_events, unsigned *pnb_apoints)
  * day. This is useful to speed up the appointment panel update.
  */
 day_items_nb_t *
-day_process_storage (date_t *slctd_date, bool day_changed,
+day_process_storage (date_t *slctd_date, unsigned day_changed,
 		     day_items_nb_t *inday)
 {
   long date;
@@ -396,7 +408,7 @@ day_write_pad (long date, int width, int length, int incolor)
   apoint_llist_node_t a;
   int line, item_number, max_pos, recur;
   const int x_pos = 0;
-  bool draw_line = false;
+  unsigned draw_line = 0;
 
   line = item_number = 0;
   max_pos = length;
@@ -419,7 +431,7 @@ day_write_pad (long date, int width, int length, int incolor)
 	  display_item (item_number - incolor, p->mesg, recur,
 			(p->note != NULL) ? 1 : 0, width - 7, line, x_pos);
 	  line++;
-	  draw_line = true;
+	  draw_line = 1;
 	}
       else
 	{
@@ -428,7 +440,7 @@ day_write_pad (long date, int width, int length, int incolor)
 	    {
 	      wmove (apad.ptrwin, line, 0);
 	      whline (apad.ptrwin, 0, width);
-	      draw_line = false;
+	      draw_line = 0;
 	    }
 	  /* Last print the appointments for current day. */
 	  item_number++;
