@@ -1,23 +1,35 @@
-/*	$calcurse: help.c,v 1.38 2009/01/04 10:22:10 culot Exp $	*/
+/*	$calcurse: help.c,v 1.41 2009-07-12 17:55:14 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -153,7 +165,7 @@ help_wins_init (scrollwin_t *hwin, int x, int y, int h, int w)
   hwin->pad.h = BUFSIZ;
   hwin->pad.w = hwin->win.w - 2 * PADOFFSET + 1;
 
-  (void)snprintf (hwin->label, BUFSIZ, _("Calcurse %s | help"), VERSION);
+  (void)snprintf (hwin->label, BUFSIZ, _("Calcurse help"));
   wins_scrollwin_init (hwin);
   wins_show (hwin->win.p, hwin->label);
 }
@@ -634,10 +646,14 @@ help_screen (void)
 
   hscr[HELP_FLAG].title = _("Flag Item\n");
   (void)snprintf (hscr[HELP_FLAG].text, HELPTEXTSIZ,
-    _("Toggle an appointment's 'important' flag.\n"
-      "If an item is flagged as important, an exclamation mark appears in front"
-      "\nof it, and you will be warned if time gets closed to the appointment\n"
-      "start time.\n"
+    _("Toggle an appointment's 'important' flag or a todo's 'completed' flag.\n"
+      "If a todo is flagged as completed, its priority number will be replaced\n"
+      "by an 'X' sign. Completed tasks will no longer appear in exported data\n"
+      "or when using the '-t' command line flag (unless specifying '0' as the\n"
+      "priority number, in which case only completed tasks will be shown).\n\n"
+      "If an appointment is flagged as important, an exclamation mark appears\n"
+      "in front of it, and you will be warned if time gets closed to the\n"
+      "appointment start time.\n"
       "To customize the way one gets notified, the configuration submenu lets\n"
       "you choose the command launched to warn user of an upcoming appointment,"
       "\nand how long before it he gets notified."));
@@ -695,16 +711,21 @@ help_screen (void)
 
   hscr[HELP_CREDITS].title = _("Calcurse - text-based organizer");
   (void)snprintf (hscr[HELP_CREDITS].text, HELPTEXTSIZ,
-    _("\nCopyright (c) 2004-2008 Frederic Culot\n"
+    _("\nCopyright (c) 2004-2009 Frederic Culot\n"
+      "All rights reserved.\n"
       "\n"
-      "This program is free software; you can redistribute it and/or modify\n"
-      "it under the terms of the GNU General Public License as published by\n"
-      "the Free Software Foundation; either version 2 of the License, or\n"
-      "(at your option) any later version.\n"
-      "\nThis program is distributed in the hope that it will be useful,\n"
-      "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-      "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-      "GNU General Public License for more details.\n"
+      "Redistribution and use in source and binary forms, with or without\n"
+      "modification, are permitted provided that the following conditions\n"
+      "are met:\n"
+      "\n"
+      "\t- Redistributions of source code must retain the above\n"
+      "\t  copyright notice, this list of conditions and the\n"
+      "\t  following disclaimer.\n"
+      "\n"
+      "\t- Redistributions in binary form must reproduce the above\n"
+      "\t  copyright notice, this list of conditions and the\n"
+      "\t  following disclaimer in the documentation and/or other\n"
+      "\t  materials provided with the distribution.\n"
       "\n\n"
       "Send your feedback or comments to : calcurse@culot.org\n"
       "Calcurse home page : http://culot.org/calcurse"));
