@@ -1,23 +1,35 @@
-/*	$calcurse: io.c,v 1.58 2009/01/24 18:45:35 culot Exp $	*/
+/*	$calcurse: io.c,v 1.68 2009-07-12 17:48:13 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -173,15 +185,16 @@ progress_bar (progress_bar_t type, int progress)
   switch (type)
     {
     case PROGRESS_BAR_SAVE:
-      EXIT_IF (progress < 0 || progress > PROGRESS_BAR_KEYS, error_msg);
+      EXIT_IF (progress < 0 || progress > PROGRESS_BAR_KEYS, "%s", error_msg);
       status_mesg (mesg_sav, file[progress]);
       break;
     case PROGRESS_BAR_LOAD:
-      EXIT_IF (progress < 0 || progress > PROGRESS_BAR_KEYS, error_msg);
+      EXIT_IF (progress < 0 || progress > PROGRESS_BAR_KEYS, "%s", error_msg);
       status_mesg (mesg_load, file[progress]);
       break;
     case PROGRESS_BAR_EXPORT:
-      EXIT_IF (progress < 0 || progress > PROGRESS_BAR_EXPORT_TODO, error_msg);
+      EXIT_IF (progress < 0
+               || progress > PROGRESS_BAR_EXPORT_TODO, "%s", error_msg);
       status_mesg (mesg_export, data[progress]);
       break;
     }
@@ -501,7 +514,7 @@ ical_export_recur_apoints (FILE *stream)
       date_sec2date_fmt (i->start, ICALDATETIMEFMT, ical_datetime);
       (void)fprintf (stream, "BEGIN:VEVENT\n");
       (void)fprintf (stream, "DTSTART:%s\n", ical_datetime);
-      (void)fprintf (stream, "DURATION:P%ldS\n", i->dur);
+      (void)fprintf (stream, "DURATION:PT%ldS\n", i->dur);
       (void)fprintf (stream, "RRULE:FREQ=%s;INTERVAL=%d",
                      ical_recur_type[i->rpt->type], i->rpt->freq);
 
@@ -604,7 +617,7 @@ ical_export_apoints (FILE *stream)
       date_sec2date_fmt (i->start, ICALDATETIMEFMT, ical_datetime);
       (void)fprintf (stream, "BEGIN:VEVENT\n");
       (void)fprintf (stream, "DTSTART:%s\n", ical_datetime);
-      (void)fprintf (stream, "DURATION:P%ldS\n", i->dur);
+      (void)fprintf (stream, "DURATION:PT%ldS\n", i->dur);
       (void)fprintf (stream, "SUMMARY:%s\n", i->mesg);
       if (i->state & APOINT_NOTIFY)
 	ical_export_valarm (stream);
@@ -634,6 +647,9 @@ ical_export_todo (FILE *stream)
 
   for (i = todolist; i != 0; i = i->next)
     {
+      if (i->id < 0)  /* completed items */
+        continue;
+      
       (void)fprintf (stream, "BEGIN:VTODO\n");
       (void)fprintf (stream, "PRIORITY:%d\n", i->id);
       (void)fprintf (stream, "SUMMARY:%s\n", i->mesg);
@@ -649,6 +665,9 @@ pcal_export_todo (FILE *stream)
   (void)fprintf (stream, "#\n# Todos\n#\n");
   for (i = todolist; i != 0; i = i->next)
     {
+      if (i->id < 0)  /* completed items */
+        continue;
+      
       (void)fprintf (stream, "note all  ");
       (void)fprintf (stream, "%d. %s\n", i->id, i->mesg);
     }
@@ -678,7 +697,8 @@ io_init (char *cfile, char *datadir)
       (void)snprintf (path_conf, BUFSIZ, "%s/" CONF_PATH_NAME, home);
       (void)snprintf (path_notes, BUFSIZ, "%s/" NOTES_DIR_NAME, home);
       (void)snprintf (path_apts, BUFSIZ, "%s/" APTS_PATH_NAME, home);
-      (void)snprintf (path_keys, BUFSIZ, "%s/" KEYS_PATH_NAME, home);      
+      (void)snprintf (path_keys, BUFSIZ, "%s/" KEYS_PATH_NAME, home);
+      (void)snprintf (path_lock, BUFSIZ, "%s/" LOCK_PATH_NAME, home);
     }
   else
     {
@@ -690,7 +710,8 @@ io_init (char *cfile, char *datadir)
       (void)snprintf (path_dir, BUFSIZ, "%s/" DIR_NAME, home);
       (void)snprintf (path_todo, BUFSIZ, "%s/" TODO_PATH, home);
       (void)snprintf (path_conf, BUFSIZ, "%s/" CONF_PATH, home);
-      (void)snprintf (path_keys, BUFSIZ, "%s/" KEYS_PATH, home);      
+      (void)snprintf (path_keys, BUFSIZ, "%s/" KEYS_PATH, home);
+      (void)snprintf (path_lock, BUFSIZ, "%s/" LOCK_PATH, home);      
       (void)snprintf (path_notes, BUFSIZ, "%s/" NOTES_DIR, home);
       if (cfile == NULL)
         {
@@ -774,16 +795,10 @@ display_mark (void)
 
 static pthread_mutex_t io_save_mutex = PTHREAD_MUTEX_INITIALIZER;
 
-/* Save the calendar data */
-void
-io_save_cal (conf_t *conf, io_save_display_t display)
+/* Save the user configuration. */
+unsigned
+io_save_conf (conf_t *conf)
 {
-  FILE *data_file;
-  struct event_s *k;
-  apoint_llist_node_t *j;
-  struct todo_s *i;
-  char theme_name[BUFSIZ];
-  char *access_pb = _("Problems accessing data file ...");
   char *config_txt =
     "#\n"
     "# Calcurse configuration file\n#\n"
@@ -794,186 +809,214 @@ io_save_cal (conf_t *conf, io_save_display_t display)
     "# For a variable to be unset its value must be blank.\n"
     "# To set a variable to the empty string its value should be \"\".\n"
     "# Lines beginning with \"#\" are comments, and ignored by Calcurse.\n";
+  char theme_name[BUFSIZ];  
+  FILE *fp;
+  
+  if ((fp = fopen (path_conf, "w")) == 0)
+    return 0;
+
+  custom_color_theme_name (theme_name);
+
+  (void)fprintf (fp, "%s\n", config_txt);
+  
+  (void)fprintf (fp, "# If this option is set to yes, "
+                 "automatic save is done when quitting\n");
+  (void)fprintf (fp, "auto_save=\n");
+  (void)fprintf (fp, "%s\n", (conf->auto_save) ? "yes" : "no");
+  
+  (void)fprintf (fp, "\n# If not null, perform automatic saves every "
+                 "'periodic_save' minutes\n");
+  (void)fprintf (fp, "periodic_save=\n");
+  (void)fprintf (fp, "%d\n", conf->periodic_save);
+  
+  (void)fprintf (fp, "\n# If this option is set to yes, "
+                 "confirmation is required before quitting\n");
+  (void)fprintf (fp, "confirm_quit=\n");
+  (void)fprintf (fp, "%s\n", (conf->confirm_quit) ? "yes" : "no");
+  
+  (void)fprintf (fp, "\n# If this option is set to yes, "
+                 "confirmation is required before deleting an event\n");
+  (void)fprintf (fp, "confirm_delete=\n");
+  (void)fprintf (fp, "%s\n", (conf->confirm_delete) ? "yes" : "no");
+  
+  (void)fprintf (fp, "\n# If this option is set to yes, "
+                 "messages about loaded and saved data will not be displayed\n");
+  (void)fprintf (fp, "skip_system_dialogs=\n");
+  (void)fprintf (fp, "%s\n", (conf->skip_system_dialogs) ? "yes" : "no");
+  
+  (void)fprintf (fp,
+                 "\n# If this option is set to yes, progress bar appearing "
+                 "when saving data will not be displayed\n");
+  (void)fprintf (fp, "skip_progress_bar=\n");
+  (void)fprintf (fp, "%s\n", (conf->skip_progress_bar) ? "yes" : "no");
+  
+  (void)fprintf (fp, "\n# If this option is set to yes, "
+                 "monday is the first day of the week, else it is sunday\n");
+  (void)fprintf (fp, "week_begins_on_monday=\n");
+  (void)fprintf (fp, "%s\n",
+                 (calendar_week_begins_on_monday ())? "yes" : "no");
+  
+  (void)fprintf (fp, "\n# This is the color theme used for menus :\n");
+  (void)fprintf (fp, "color-theme=\n");
+  (void)fprintf (fp, "%s\n", theme_name);
+  
+  (void)fprintf (fp, "\n# This is the layout of the calendar :\n");
+  (void)fprintf (fp, "layout=\n");
+  (void)fprintf (fp, "%d\n", wins_layout ());
+  
+  if (ui_mode == UI_CURSES)
+    pthread_mutex_lock (&nbar.mutex);
+  (void)fprintf (fp,
+                 "\n# If this option is set to yes, "
+                 "notify-bar will be displayed :\n");
+  (void)fprintf (fp, "notify-bar_show=\n");
+  (void)fprintf (fp, "%s\n", (nbar.show) ? "yes" : "no");
+  
+  (void)fprintf (fp,
+                 "\n# Format of the date to be displayed inside notify-bar :\n");
+  (void)fprintf (fp, "notify-bar_date=\n");
+  (void)fprintf (fp, "%s\n", nbar.datefmt);
+  
+  (void)fprintf (fp,
+                 "\n# Format of the time to be displayed inside notify-bar :\n");
+  (void)fprintf (fp, "notify-bar_clock=\n");
+  (void)fprintf (fp, "%s\n", nbar.timefmt);
+  
+  (void)fprintf (fp,
+                 "\n# Warn user if he has an appointment within next "
+                 "'notify-bar_warning' seconds :\n");
+  (void)fprintf (fp, "notify-bar_warning=\n");
+  (void)fprintf (fp, "%d\n", nbar.cntdwn);
+  
+  (void)fprintf (fp, "\n# Command used to notify user of "
+                 "an upcoming appointment :\n");
+  (void)fprintf (fp, "notify-bar_command=\n");
+  (void)fprintf (fp, "%s\n", nbar.cmd);
+  
+  (void)fprintf (fp, "\n# Format of the date to be displayed "
+                 "in non-interactive mode :\n");
+  (void)fprintf (fp, "output_datefmt=\n");
+  (void)fprintf (fp, "%s\n", conf->output_datefmt);
+  
+  (void)fprintf (fp, "\n# Format to be used when entering a date "
+                 "(1)mm/dd/yyyy (2)dd/mm/yyyy (3)yyyy/mm/dd) "
+                 "(4)yyyy-mm-dd:\n");
+  (void)fprintf (fp, "input_datefmt=\n");
+  (void)fprintf (fp, "%d\n", conf->input_datefmt);
+  
+  if (ui_mode == UI_CURSES)
+    pthread_mutex_unlock (&nbar.mutex);
+  
+  file_close (fp, __FILE_POS__);
+
+  return 1;
+}
+
+/* 
+ * Save the apts data file, which contains the 
+ * appointments first, and then the events. 
+ * Recursive items are written first.
+ */
+unsigned
+io_save_apts (void)
+{
+  apoint_llist_node_t *a;
+  struct event_s *e;  
+  FILE *fp;
+
+  if ((fp = fopen (path_apts, "w")) == 0)
+    return 0;
+
+  recur_save_data (fp);
+
+  if (ui_mode == UI_CURSES)
+    pthread_mutex_lock (&(alist_p->mutex));
+  for (a = alist_p->root; a != 0; a = a->next)
+    apoint_write (a, fp);
+  if (ui_mode == UI_CURSES)
+    pthread_mutex_unlock (&(alist_p->mutex));
+
+  for (e = eventlist; e != 0; e = e->next)
+    event_write (e, fp);
+  file_close (fp, __FILE_POS__);
+
+  return 1;
+}
+
+/* Save the todo data file. */
+unsigned
+io_save_todo (void)
+{
+  struct todo_s *t;  
+  FILE *fp;
+  
+  if ((fp = fopen (path_todo, "w")) == 0)
+    return 0;
+
+  for (t = todolist; t != 0; t = t->next)
+    {
+      if (t->note)
+        (void)fprintf (fp, "[%d]>%s %s\n", t->id, t->note, t->mesg);
+      else
+        (void)fprintf (fp, "[%d] %s\n", t->id, t->mesg);
+    }
+  file_close (fp, __FILE_POS__);
+
+  return 1;
+}
+
+/* Save user-defined keys */
+unsigned
+io_save_keys (void)
+{
+  FILE *fp;
+  
+  if ((fp = fopen (path_keys, "w")) == 0)
+    return 0;
+  
+  keys_save_bindings (fp);
+  file_close (fp, __FILE_POS__);
+
+  return 1;
+}
+
+/* Save the calendar data */
+void
+io_save_cal (conf_t *conf, io_save_display_t display)
+{
+  char *access_pb = _("Problems accessing data file ...");
   char *save_success = _("The data files were successfully saved");
   char *enter = _("Press [ENTER] to continue");
-  bool show_bar = false;
+  int show_bar;
 
   pthread_mutex_lock (&io_save_mutex);
-  
+
+  show_bar = 0;  
   if (ui_mode == UI_CURSES && display == IO_SAVE_DISPLAY_BAR
       && !conf->skip_progress_bar)
-    show_bar = true;
+    show_bar = 1;
   else if (ui_mode == UI_CURSES && display == IO_SAVE_DISPLAY_MARK)
     display_mark ();
-  
-  /* Save the user configuration. */
+
   if (show_bar)
     progress_bar (PROGRESS_BAR_SAVE, PROGRESS_BAR_CONF);
+  if (!io_save_conf (conf))
+    ERROR_MSG ("%s", access_pb);
   
-  data_file = fopen (path_conf, "w");
-  if (data_file == NULL)
-    ERROR_MSG (access_pb);
-  else
-    {
-      custom_color_theme_name (theme_name);
-
-      (void)fprintf (data_file, "%s\n", config_txt);
-
-      (void)fprintf (data_file,
-                     "# If this option is set to yes, "
-                     "automatic save is done when quitting\n");
-      (void)fprintf (data_file, "auto_save=\n");
-      (void)fprintf (data_file, "%s\n", (conf->auto_save) ? "yes" : "no");
-
-      (void)fprintf (data_file,
-                     "\n# If not null, perform automatic saves every "
-                     "'periodic_save' minutes\n");
-      (void)fprintf (data_file, "periodic_save=\n");
-      (void)fprintf (data_file, "%d\n", conf->periodic_save);
-      
-      (void)fprintf (data_file,
-                     "\n# If this option is set to yes, "
-                     "confirmation is required before quitting\n");
-      (void)fprintf (data_file, "confirm_quit=\n");
-      (void)fprintf (data_file, "%s\n", (conf->confirm_quit) ? "yes" : "no");
-
-      (void)fprintf (data_file,
-                     "\n# If this option is set to yes, "
-                     "confirmation is required before deleting an event\n");
-      (void)fprintf (data_file, "confirm_delete=\n");
-      (void)fprintf (data_file, "%s\n", (conf->confirm_delete) ? "yes" : "no");
-
-      (void)fprintf (data_file,
-                     "\n# If this option is set to yes, "
-                     "messages about loaded and saved data will not be displayed\n");
-      (void)fprintf (data_file, "skip_system_dialogs=\n");
-      (void)fprintf (data_file, "%s\n", (conf->skip_system_dialogs) ? "yes" : "no");
-
-      (void)fprintf (data_file,
-                     "\n# If this option is set to yes, progress bar appearing "
-                     "when saving data will not be displayed\n");
-      (void)fprintf (data_file, "skip_progress_bar=\n");
-      (void)fprintf (data_file, "%s\n", (conf->skip_progress_bar) ? "yes" : "no");
-
-      (void)fprintf (data_file,
-                     "\n# If this option is set to yes, "
-                     "monday is the first day of the week, else it is sunday\n");
-      (void)fprintf (data_file, "week_begins_on_monday=\n");
-      (void)fprintf (data_file, "%s\n",
-                     (calendar_week_begins_on_monday ())? "yes" : "no");
- 
-      (void)fprintf (data_file, "\n# This is the color theme used for menus :\n");
-      (void)fprintf (data_file, "color-theme=\n");
-      (void)fprintf (data_file, "%s\n", theme_name);
-
-      (void)fprintf (data_file, "\n# This is the layout of the calendar :\n");
-      (void)fprintf (data_file, "layout=\n");
-      (void)fprintf (data_file, "%d\n", wins_layout ());
-
-      if (ui_mode == UI_CURSES)
-        pthread_mutex_lock (&nbar.mutex);
-      (void)fprintf (data_file,
-                     "\n# If this option is set to yes, "
-                     "notify-bar will be displayed :\n");
-      (void)fprintf (data_file, "notify-bar_show=\n");
-      (void)fprintf (data_file, "%s\n", (nbar.show) ? "yes" : "no");
-
-      (void)fprintf (data_file,
-                     "\n# Format of the date to be displayed inside notify-bar :\n");
-      (void)fprintf (data_file, "notify-bar_date=\n");
-      (void)fprintf (data_file, "%s\n", nbar.datefmt);
-
-      (void)fprintf (data_file,
-                     "\n# Format of the time to be displayed inside notify-bar :\n");
-      (void)fprintf (data_file, "notify-bar_clock=\n");
-      (void)fprintf (data_file, "%s\n", nbar.timefmt);
-
-      (void)fprintf (data_file,
-                     "\n# Warn user if he has an appointment within next "
-                     "'notify-bar_warning' seconds :\n");
-      (void)fprintf (data_file, "notify-bar_warning=\n");
-      (void)fprintf (data_file, "%d\n", nbar.cntdwn);
-
-      (void)fprintf (data_file,
-                     "\n# Command used to notify user of "
-                     "an upcoming appointment :\n");
-      (void)fprintf (data_file, "notify-bar_command=\n");
-      (void)fprintf (data_file, "%s\n", nbar.cmd);
-
-      (void)fprintf (data_file,
-                     "\n# Format of the date to be displayed "
-                     "in non-interactive mode :\n");
-      (void)fprintf (data_file, "output_datefmt=\n");
-      (void)fprintf (data_file, "%s\n", conf->output_datefmt);
-
-      (void)fprintf (data_file,
-                     "\n# Format to be used when entering a date "
-                     "(1)mm/dd/yyyy (2)dd/mm/yyyy (3)yyyy/mm/dd) "
-                     "(4)yyyy-mm-dd:\n");
-      (void)fprintf (data_file, "input_datefmt=\n");
-      (void)fprintf (data_file, "%d\n", conf->input_datefmt);
-
-      if (ui_mode == UI_CURSES)
-        pthread_mutex_unlock (&nbar.mutex);
-
-      file_close (data_file, __FILE_POS__);
-    }
-
-  /* Save the todo data file. */
   if (show_bar)
     progress_bar (PROGRESS_BAR_SAVE, PROGRESS_BAR_TODO);
-  data_file = fopen (path_todo, "w");
-  if (data_file == NULL)
-    ERROR_MSG (access_pb);
-  else
-    {
-      for (i = todolist; i != 0; i = i->next)
-	{
-	  if (i->note != NULL)
-	    (void)fprintf (data_file, "[%d]>%s %s\n", i->id, i->note, i->mesg);
-	  else
-	    (void)fprintf (data_file, "[%d] %s\n", i->id, i->mesg);
-	}
-      file_close (data_file, __FILE_POS__);
-    }
-
-  /* 
-   * Save the apts data file, which contains the 
-   * appointments first, and then the events. 
-   * Recursive items are written first.
-   */
+  if (!io_save_todo ())
+    ERROR_MSG ("%s", access_pb);
+  
   if (show_bar)
     progress_bar (PROGRESS_BAR_SAVE, PROGRESS_BAR_APTS);
-  data_file = fopen (path_apts, "w");
-  if (data_file == NULL)
-    ERROR_MSG (access_pb);
-  else
-    {
-      recur_save_data (data_file);
-
-      if (ui_mode == UI_CURSES)
-        pthread_mutex_lock (&(alist_p->mutex));
-      for (j = alist_p->root; j != 0; j = j->next)
-	apoint_write (j, data_file);
-      if (ui_mode == UI_CURSES)
-        pthread_mutex_unlock (&(alist_p->mutex));
-
-      for (k = eventlist; k != 0; k = k->next)
-	event_write (k, data_file);
-      file_close (data_file, __FILE_POS__);
-    }
-
-  /* Save user-defined keys */
+  if (!io_save_apts ())
+    ERROR_MSG ("%s", access_pb);
+  
   if (show_bar)
     progress_bar (PROGRESS_BAR_SAVE, PROGRESS_BAR_KEYS);
-  data_file = fopen (path_keys, "w");
-  if (data_file == NULL)
-    ERROR_MSG (access_pb);
-  else
-    {
-      keys_save_bindings (data_file);
-      file_close (data_file, __FILE_POS__);
-    }
+  if (!io_save_keys ())
+    ERROR_MSG ("%s", access_pb);
   
   /* Print a message telling data were saved */
   if (ui_mode == UI_CURSES && !conf->skip_system_dialogs
@@ -1423,15 +1466,16 @@ check_directory (char *dir, int *missing)
     (*missing)++;
 }
 
-static void
-check_file (char *file, int *missing)
+void
+io_check_file (char *file, int *missing)
 {
   FILE *fd;
 
   errno = 0;
   if ((fd = fopen (file, "r")) == NULL)
     {
-      (*missing)++;
+      if (missing)
+        (*missing)++;
       if ((fd = fopen (file, "w")) == NULL)
 	{
 	  (void)fprintf (stderr, _("FATAL ERROR: could not create %s: %s\n"),
@@ -1463,10 +1507,10 @@ io_check_data_files (void)
   errno = 0;
   check_directory (path_dir, &missing);
   check_directory (path_notes, &missing);
-  check_file (path_todo, &missing);
-  check_file (path_apts, &missing);
-  check_file (path_conf, &missing);
-  check_file (path_keys, &missing_keys);
+  io_check_file (path_todo, &missing);
+  io_check_file (path_apts, &missing);
+  io_check_file (path_conf, &missing);
+  io_check_file (path_keys, &missing_keys);
   if (missing_keys)
     {
       missing++;
@@ -1478,7 +1522,7 @@ io_check_data_files (void)
 
 /* Draw the startup screen */
 void
-io_startup_screen (bool skip_dialogs, int no_data_file)
+io_startup_screen (unsigned skip_dialogs, int no_data_file)
 {
   char *welcome_mesg =
     _("Welcome to Calcurse. Missing data files were created.");
@@ -1626,17 +1670,29 @@ ical_store_todo (int priority, char *mesg, char *note)
 }
 
 static void
-ical_store_event (char *mesg, char *note, long day, ical_rpt_t *rpt,
+ical_store_event (char *mesg, char *note, long day, long end, ical_rpt_t *rpt,
                   days_t *exc)
 {
   const int EVENTID = 1;
   
-  if (rpt != NULL)
+  if (rpt)
     {
       recur_event_new (mesg, note, day, EVENTID, rpt->type, rpt->freq,
                        rpt->until, &exc);
       mem_free (rpt);
     }
+  else if (end && end != day)
+    {
+      /* Here we have an event that spans over several days. */
+      rpt = mem_malloc (sizeof (ical_rpt_t));
+      rpt->type = RECUR_DAILY;
+      rpt->freq = 1;
+      rpt->count = 0;
+      rpt->until = end;
+      recur_event_new (mesg, note, day, EVENTID, rpt->type, rpt->freq,
+                       rpt->until, &exc);
+      mem_free (rpt);
+    }
   else
     {
       event_new (mesg, note, day, EVENTID);
@@ -1769,7 +1825,7 @@ ical_unfold_content (FILE *fd, char *line, unsigned *lineno)
                   return NULL;
                 }
               newsize = strlen (content) + strlen (tmpline) + 1;
-              if ((rline = mem_realloc (content, newsize)) == NULL)
+              if ((rline = mem_realloc (content, newsize, 1)) == NULL)
                 {
                   mem_free (content);
                   mem_free (tmpline);
@@ -2355,9 +2411,10 @@ ical_read_event (FILE *fdi, FILE *log, unsigned *noevents, unsigned *noapoints,
                       else if (vevent.start == vevent.end)
                         {
                           vevent_type = EVENT;
+                          vevent.end = 0L;
                           ical_store_event (vevent.mesg, vevent.note,
-                                            vevent.start, vevent.rpt,
-                                            vevent.exc);
+                                            vevent.start, vevent.end,
+                                            vevent.rpt, vevent.exc);
                           (*noevents)++;
                           return;
                         }
@@ -2378,8 +2435,14 @@ ical_read_event (FILE *fdi, FILE *log, unsigned *noevents, unsigned *noapoints,
                   (*noapoints)++;
                   break;
                 case EVENT:
+                  if (vevent.start == 0)
+                    {
+                      ical_log (log, ICAL_VEVENT, ITEMLINE, 
+                                _("event date is not defined."));
+                      goto cleanup;
+                    }
                   ical_store_event (vevent.mesg, vevent.note, vevent.start,
-                                    vevent.rpt, vevent.exc);
+                                    vevent.end, vevent.rpt, vevent.exc);
                   (*noevents)++;
                   break;
                 case UNDEFINED:
@@ -2819,3 +2882,48 @@ io_stop_psave_thread (void)
   if (io_t_psave)
     pthread_cancel (io_t_psave);  
 }
+
+/*
+ * This sets a lock file to prevent from having two different instances of
+ * calcurse running.
+ * If the lock cannot be obtained, then warn the user and exit calcurse.
+ * Else, create a .calcurse.lock file in the user defined directory, which
+ * will be removed when calcurse exits.
+ *
+ * Note: when creating the lock file, the interactive mode is not initialized
+ * yet.
+ */
+void
+io_set_lock (void)
+{
+  FILE *lock;
+
+  if ((lock = fopen (path_lock, "r")) != NULL)
+    {
+      (void)fprintf (stderr,
+                     _("\nWARNING: it seems that another calcurse instance is "
+                       "already running.\n"
+                       "If this is not the case, please remove the following "
+                       "lock file: \n\"%s\"\n"
+                       "and restart calcurse.\n"), path_lock);
+      exit (EXIT_FAILURE);
+    }
+  else
+    {
+      if ((lock = fopen (path_lock, "w")) == NULL)
+	{
+	  (void)fprintf (stderr, _("FATAL ERROR: could not create %s: %s\n"),
+                         path_lock, strerror (errno));
+	  exit_calcurse (EXIT_FAILURE);
+	}
+      (void)fclose (lock);
+    }
+}  
+
+/* Used when calcurse exits to remove the lock file. */
+void
+io_unset_lock (void)
+{
+  if (unlink (path_lock) != 0)
+    EXIT (_("Could not remove lock file: %s\n"), strerror (errno));
+}
