@@ -1,23 +1,35 @@
-/*	$calcurse: notify.c,v 1.36 2009/01/22 18:11:57 culot Exp $	*/
+/*	$calcurse: notify.c,v 1.40 2009-07-12 17:55:14 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -45,6 +57,21 @@ static struct notify_app_s    notify_app;
 static pthread_attr_t         detached_thread_attr;
 static pthread_t              notify_t_main;
 
+/*
+ * This is used to update the notify_app structure.
+ * Note: the mutex associated with this structure must be locked by the
+ * caller!
+ */
+static void
+notify_update_app (long start, char state, char *msg)
+{
+  notify_free_app ();
+  notify_app.got_app = 1;
+  notify_app.time = start;
+  notify_app.state = state;  
+  notify_app.txt = mem_strdup (msg);
+}
+
 /* Return 1 if we need to display the notify-bar, else 0. */
 int
 notify_bar (void)
@@ -108,10 +135,21 @@ notify_init_bar (void)
   pthread_mutex_init (&notify.mutex, NULL);
   pthread_mutex_init (&notify_app.mutex, NULL);
   notify_app.got_app = 0;
+  notify_app.txt = 0;
   notify.win = newwin (win[NOT].h, win[NOT].w, win[NOT].y, win[NOT].x);
   extract_aptsfile ();
 }
 
+/*
+ * Free memory associated with the notify_app structure.
+ */
+void
+notify_free_app (void)
+{
+  if (notify_app.txt)
+    mem_free (notify_app.txt);
+}
+
 /* Stop the notify-bar main thread. */
 void
 notify_stop_main_thread (void)
@@ -292,14 +330,13 @@ notify_thread_app (void *arg)
   pthread_mutex_lock (&notify_app.mutex);
   if (tmp_app.got_app)
     {
-      notify_app.got_app = 1;
-      notify_app.time = tmp_app.time;
-      notify_app.txt = mem_strdup (tmp_app.txt);
-      notify_app.state = tmp_app.state;
+      notify_update_app (tmp_app.time, tmp_app.state, tmp_app.txt);
     }
   else
     {
+      notify_free_app ();
       notify_app.got_app = 0;
+      notify_app.txt = 0;
     }
   pthread_mutex_unlock (&notify_app.mutex);
 
@@ -346,10 +383,7 @@ notify_check_added (char *mesg, long start, char state)
 
   if (update_notify)
     {
-      notify_app.got_app = 1;
-      notify_app.time = start;
-      notify_app.txt = mem_strdup (mesg);
-      notify_app.state = state;
+      notify_update_app (start, state, mesg);
     }
   pthread_mutex_unlock (&notify_app.mutex);
   notify_update_bar ();
@@ -385,10 +419,7 @@ notify_check_repeated (recur_apoint_llist_node_t *i)
     }
   if (update_notify)
     {
-      notify_app.got_app = 1;
-      notify_app.time = real_app_time;
-      notify_app.txt = mem_strdup (i->mesg);
-      notify_app.state = i->state;
+      notify_update_app (real_app_time, i->state, i->mesg);
     }
   pthread_mutex_unlock (&notify_app.mutex);
   notify_update_bar ();
@@ -537,8 +568,7 @@ notify_config_bar (void)
   int ch = 0, change_win = 1;
 
   buf = mem_malloc (BUFSIZ);
-  (void)snprintf (label, BUFSIZ, _("CalCurse %s | notify-bar options"),
-                  VERSION);
+  (void)snprintf (label, BUFSIZ, _("notify-bar options"));
   
   conf_win.p = 0;
   custom_confwin_init (&conf_win, label);
