@@ -1,23 +1,35 @@
-/*	$calcurse: todo.c,v 1.31 2009/01/03 21:32:11 culot Exp $	*/
+/*	$calcurse: todo.c,v 1.34 2009-07-12 16:22:01 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2008 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -154,19 +166,30 @@ todo_new_item (void)
     }
 }
 
-/* Add an item in the todo linked list. */
+/*
+ * Add an item in the todo linked list.
+ */
 struct todo_s *
 todo_add (char *mesg, int id, char *note)
 {
   struct todo_s *o, **i;
+  int absid;
+  
   o = (struct todo_s *) mem_malloc (sizeof (struct todo_s));
   o->mesg = mem_strdup (mesg);
   o->id = id;
   o->note = (note != NULL && note[0] != '\0') ? mem_strdup (note) : NULL;
   i = &todolist;
+
+  /*
+   * As of version 2.6, todo items can have a negative id, which means they
+   * were completed. To keep them sorted, we need to consider the absolute id
+   * value.
+   */
+  absid = abs (id);
   for (;;)
     {
-      if (*i == 0 || (*i)->id > id)
+      if (*i == 0 || abs ((*i)->id) > absid)
 	{
 	  o->next = *i;
 	  *i = o;
@@ -229,6 +252,21 @@ todo_delete_bynum (unsigned num, erase_flag_e flag)
   EXIT (_("no such todo"));
 }
 
+/*
+ * Flag a todo item (for now on, only the 'completed' state is available).
+ * Internally, a completed item keeps its priority, but it becomes negative.
+ * This way, it is easy to retrive its original priority if the user decides
+ * that in fact it was not completed.
+ */
+void
+todo_flag (void)
+{
+  struct todo_s *t;
+
+  t = todo_get_item (hilt);
+  t->id = -t->id;
+}
+
 /* Delete an item from the ToDo list. */
 void
 todo_delete (conf_t *conf)
@@ -239,7 +277,7 @@ todo_delete (conf_t *conf)
       _("This item has a note attached to it. "
 	"Delete (t)odo or just its (n)ote ?");
   char *erase_choice = _("[t/n] ");
-  bool go_for_todo_del = false;
+  unsigned go_for_todo_del = 0;
   int answer, has_note;
 
   if (conf->confirm_delete)
@@ -248,7 +286,7 @@ todo_delete (conf_t *conf)
       answer = wgetch (win[STA].p);
       if ((answer == 'y') && (todos > 0))
 	{
-	  go_for_todo_del = true;
+	  go_for_todo_del = 1;
 	}
       else
 	{
@@ -257,9 +295,9 @@ todo_delete (conf_t *conf)
 	}
     }
   else if (todos > 0)
-    go_for_todo_del = true;
+    go_for_todo_del = 1;
 
-  if (go_for_todo_del == false)
+  if (go_for_todo_del == 0)
     {
       wins_erase_status_bar ();
       return;
@@ -350,7 +388,7 @@ todo_chg_priority (int action)
       (backup_id > 1) ? backup_id-- : do_chg--;
       break;
     case KEY_LOWER_PRIORITY:
-      (backup_id < 9) ? backup_id++ : do_chg--;
+      (backup_id > 0 && backup_id < 9) ? backup_id++ : do_chg--;
       break;
     default:
       EXIT (_("no such action"));
@@ -383,19 +421,24 @@ display_todo_item (int incolor, char *msg, int prio, int note, int len, int y,
 {
   WINDOW *w;
   int ch_note;
-  char buf[len];
+  char buf[len], priostr[2];
 
   w = win[TOD].p;
   ch_note = (note) ? '>' : '.';
+  if (prio > 0)
+    snprintf (priostr, sizeof priostr, "%d", prio);
+  else
+    snprintf (priostr, sizeof priostr, "X");
+    
   if (incolor == 0)
     custom_apply_attr (w, ATTR_HIGHEST);
   if (strlen (msg) < len)
-    mvwprintw (w, y, x, "%d%c %s", prio, ch_note, msg);
+    mvwprintw (w, y, x, "%s%c %s", priostr, ch_note, msg);
   else
     {
       (void)strncpy (buf, msg, len - 1);
       buf[len - 1] = '\0';
-      mvwprintw (w, y, x, "%d%c %s...", prio, ch_note, buf);
+      mvwprintw (w, y, x, "%s%c %s...", priostr, ch_note, buf);
     }
   if (incolor == 0)
     custom_remove_attr (w, ATTR_HIGHEST);
@@ -440,7 +483,7 @@ todo_update_panel (int which_pan)
       float ratio = ((float) max_items) / ((float) todos);
       int sbar_length = (int) (ratio * (max_items + 1));
       int highend = (int) (ratio * first);
-      bool hilt_bar = (which_pan == TOD) ? true : false;
+      unsigned hilt_bar = (which_pan == TOD) ? 1 : 0;
       int sbar_top = highend + title_lines;
 
       if ((sbar_top + sbar_length) > win[TOD].h - 1)
