@@ -1,23 +1,35 @@
-/*	$calcurse: utils.c,v 1.68 2009/01/24 14:44:25 culot Exp $	*/
+/*	$calcurse: utils.c,v 1.76 2009-07-12 17:48:14 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2004-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -51,13 +63,20 @@
 void
 exit_calcurse (int status)
 {
+  int remove_lock;
+  
   if (ui_mode == UI_CURSES)
     {
+      notify_stop_main_thread ();
       clear ();
       refresh ();
       endwin ();
       ui_mode = UI_CMDLINE;
+      remove_lock = 1;
     }
+  else
+    remove_lock = 0;
+  
   calendar_stop_date_thread ();
   io_stop_psave_thread ();
   day_free_list ();
@@ -70,8 +89,12 @@ exit_calcurse (int status)
   recur_apoint_free_bkp (ERASE_FORCE);
   recur_event_free_bkp (ERASE_FORCE);
   todo_free_list ();
+  notify_free_app ();
   keys_free ();
   mem_stats ();
+  if (remove_lock)
+    io_unset_lock ();
+  
   exit (status);
 }
 
@@ -316,7 +339,7 @@ getstring (WINDOW *win, char *str, int l, int x, int y)
 	case 330:
 	case 127:
 	case CTRL ('H'):
-	  if (len > 0)
+	  if (len > 0 && newpos > x)
 	    {
 	      --newpos;
 	      --len;
@@ -408,7 +431,7 @@ updatestring (WINDOW *win, char **str, int x, int y)
   if (!escape)
     {
       len = strlen (newstr) + 1;
-      *str = mem_realloc (*str, len);
+      *str = mem_realloc (*str, len, 1);
       EXIT_IF (*str == 0, _("out of memory"));
       (void) memcpy (*str, newstr, len);
     }
@@ -667,7 +690,7 @@ check_time (char *string)
  */
 void
 draw_scrollbar (WINDOW *win, int y, int x, int length,
-		int bar_top, int bar_bottom, bool hilt)
+		int bar_top, int bar_bottom, unsigned hilt)
 {
   mvwvline (win, bar_top, x, ACS_VLINE, bar_bottom - bar_top);
   if (hilt)
@@ -756,17 +779,17 @@ mystrtol (const char *str)
 
 /* Print the given option value with appropriate color. */
 void
-print_bool_option_incolor (WINDOW *win, bool option, int pos_y, int pos_x)
+print_bool_option_incolor (WINDOW *win, unsigned option, int pos_y, int pos_x)
 {
   int color = 0;
   char option_value[BUFSIZ] = "";
 
-  if (option == true)
+  if (option == 1)
     {
       color = ATTR_TRUE;
       strncpy (option_value, _("yes"), BUFSIZ);
     }
-  else if (option == false)
+  else if (option == 0)
     {
       color = ATTR_FALSE;
       strncpy (option_value, _("no"), BUFSIZ);
@@ -808,7 +831,7 @@ new_tempfile (const char *prefix, int trailing_len)
 	  unlink (fullname);
 	  close (fd);
 	}
-      ERROR_MSG (_("temporary file could not be created"));
+      ERROR_MSG (_("temporary file \"%s\" could not be created"), fullname);
       return (char *)0;
     }
   fclose (file);
