@@ -1,23 +1,35 @@
-/*	$calcurse: wins.c,v 1.23 2009/01/03 21:32:11 culot Exp $	*/
+/*	$calcurse: wins.c,v 1.26 2009-07-12 16:22:03 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2007-2009 Frederic Culot
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Copyright (c) 2007-2009 Frederic Culot <frederic@culot.org>
+ * All rights reserved.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *      - Redistributions of source code must retain the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer.
+ *
+ *      - Redistributions in binary form must reproduce the above
+ *        copyright notice, this list of conditions and the
+ *        following disclaimer in the documentation and/or other
+ *        materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Send your feedback or comments to : calcurse@culot.org
  * Calcurse home page : http://culot.org/calcurse
@@ -163,7 +175,7 @@ wins_scrollwin_display (scrollwin_t *sw)
       if ((sbar_top + sbar_length) > sw->win.h - 1)
         sbar_length = sw->win.h - sbar_top;
       draw_scrollbar (sw->win.p, sbar_top, sw->win.w + sw->win.x - 2,
-                      sbar_length, sw->pad.y + 1, sw->win.h - 1, true);
+                      sbar_length, sw->pad.y + 1, sw->win.h - 1, 1);
     }
   wmove (win[STA].p, 0, 0);
   wnoutrefresh (sw->win.p);
@@ -481,7 +493,7 @@ wins_launch_external (const char *file, const char *cmd)
 
 #define NB_CAL_CMDS	24	/* number of commands while in cal view */
 #define NB_APP_CMDS	31	/* same thing while in appointment view */
-#define NB_TOD_CMDS	29	/* same thing while in todo view */
+#define NB_TOD_CMDS	30	/* same thing while in todo view */
 #define TOTAL_CMDS	NB_CAL_CMDS + NB_APP_CMDS + NB_TOD_CMDS
 #define CMDS_PER_LINE	6	/* max number of commands per line */  
 
@@ -551,8 +563,8 @@ wins_status_bar (void)
     &othr,
     /* todo keys */
     &help, &quit, &save, &chgvu, &import, &export, &add, &del, &edit, &view,
-    &draw, &othr, &rprio, &lprio, &enote, &vnote, &up, &down, &gnday, &gpday,
-    &gnweek, &gpweek, &togo, &othr, &today, &conf, &appt, &todo, &othr
+    &flag, &othr, &rprio, &lprio, &enote, &vnote, &up, &down, &gnday, &gpday,
+    &gnweek, &gpweek, &togo, &othr, &today, &conf, &appt, &todo, &draw, &othr
   };
 
   /* Drawing the keybinding with attribute and label without. */
